==> vtigercrm-5.3.0p0.tgz: modules/uploads/language/hu_hu.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 *********************************************************************************
/*********************************************************************************
 * $Header:  E:\D_root\Dokumentumok\vtiger520\hungarian52\trunk\modules\uploads\language\hu_hu.lang.php - 22:40 2010.05.21.. $
 * Description:  Defines the Hungarian language pack for the uploads module vtiger 5.2.0
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Istvan Holbok,  e-mail: holbok@gmail.com , mobil: +3670-3420900 , Skype: holboki
 ********************************************************************************/

$mod_strings = Array(

//Added fields for uploads (attach files)
'LBL_ATTACH_FILE'=>'Fájl Csatolmány',
'LBL_ATTACH'=>'Csatol',
'LBL_CANCEL'=>'Visszavon',
'LBL_STEP_SELECT_FILE'=>'1. Lépés : Fájl kiválasztása',
'LBL_BROWSE_FILES'=>'Kattints a Talózás... gombra és válaszd ki a csatolandó fájlt.',
'LBL_DESCRIPTION'=>'2. Lépés : Írj egy megjegyzést',
'LBL_OPTIONAL'=>'(opcionális)',
);

?>

==> vtigercrm-5.4.0.tgz: modules/uploads/language/hu_hu.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 *********************************************************************************
 * $Header:  \modules\uploads\language\hu_hu.lang.php - 12:14 2011.11.12. $
 * Description:  Defines the Hungarian language pack for the uploads module vtiger 5.3.x
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Istvan Holbok,  e-mail: holbok@gmail.com , mobil: +3670-3420900 , Skype: holboki
 ********************************************************************************/
$mod_strings = array(
	'LBL_ATTACH_FILE' => 'Fájl Csatolmány',
	'LBL_ATTACH' => 'Csatol',
	'LBL_CANCEL' => 'Visszavon',
	'LBL_STEP_SELECT_FILE' => '1. Lépés : Fájl kiválasztása',
	'LBL_BROWSE_FILES' => 'Kattints a Tallózás/Fájl kiválasztás... gombra és válaszd ki a csatolandó fájlt.',
	'LBL_DESCRIPTION' => '2. Lépés : Írj egy megjegyzést',
	'LBL_OPTIONAL' => '(opcionális)'
);
?>
